#!/bin/bash

# Copyright (C) 2018 Oracle. All rights reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, version 2.  This program is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.  You should have received a copy of the GNU
# General Public License along with this program; if not, write to the Free
# Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 021110-1307, USA.
#============================================================================
# This script identify and installs packages required to setup new set of 
# yum repository definition files based on current yum repository configuration
#
# Usage:
#
#  ol_yum_configure.sh
#
#============================================================================

restore()
{
for file in `ls -1 /etc/yum.repos.d/*-ol7.repo`
do
  mv $file ${file}.disabled
done

   mv /etc/yum.repos.d/public-yum-ol7.repo.sav /etc/yum.repos.d/public-yum-ol7.repo
   rm -f $REPOLIST_FILE $REPOLIST_FILE_NEW $RUN_FILE
   
}

trap 'restore' 2 6 9 15

UserId=`id -u`
if [ $UserId != 0 ]; then
   echo This script should to be run as root user
   exit
fi
if [ ! -f /etc/yum.repos.d/public-yum-ol7.repo ]; then
  echo "Missing /etc/yum.repos.d/public-yum-ol7.repo. Exiting "
  exit
fi

PACKAGE_LIST="ceph php nodejs epel gluster oci-included ksplice spacewalk.*server spacewalk.*client mysql software openstack oraclelinux_developer patch developer oracle golang"
REPOLIST_FILE=/tmp/.oracle_enable_repolist
REPOLIST_FILE_NEW=/tmp/.oracle_enable_repolist_new
RUN_FILE=/etc/yum.repos.d/.ol_yum_configure

touch $RUN_FILE

yum-config-manager | grep ol7 | grep "^\[" | egrep -v -e "x86_64|aarch64" |  sed -e "s|\[||" | sed -e "s|\]||" > $REPOLIST_FILE

PACKAGE_TO_INSTALL=
SPCWLK_SERVER=no
OCI_ONLY=no
for pkg in $PACKAGE_LIST
do
   PACKAGE_NAME=
   if grep -i "$pkg" $REPOLIST_FILE > /dev/null ; then
      if [ $pkg = ksplice -o $pkg = patch ]; then
       OCI_ONLY=yes
      fi
      if [ $pkg = developer ]; then
        if  egrep -i -e "$pkg$|${pkg} |${pkg}_UEKR5|${pkg}_kvm" $REPOLIST_FILE > /dev/null ; then
        PACKAGE_NAME=oraclelinux-developer-release-el7
        fi
      elif [ $pkg = patch ]; then
        PACKAGE_NAME=oraclelinux-patchonly-release-el7
      elif [ "$pkg" = 'spacewalk.*server' ]; then
        PACKAGE_NAME=oracle-spacewalk-server-release-el7
        SPCWLK_SERVER=yes
      elif [ "$pkg" = 'spacewalk.*client' ]; then
       PACKAGE_NAME=oracle-spacewalk-client-release-el7
      elif [ $pkg = "software" ]; then
        PACKAGE_NAME=oracle-softwarecollection-release-el7
      elif [ $pkg = 'ceph' -o $pkg = 'php' -o $pkg = 'golang' -o $pkg = 'nodejs' -o $pkg = 'epel' -o $pkg = 'openstack' -o $pkg = 'gluster' ]; then
        PACKAGE_NAME=oracle-${pkg}-release-el7
      else
        PACKAGE_NAME=${pkg}-release-el7
      fi
   PACKAGE_TO_INSTALL="$PACKAGE_TO_INSTALL $PACKAGE_NAME"
   fi
done
if [ ! -z "$PACKAGE_TO_INSTALL" ]; then
RPM_INSTALL=no
if [ $SPCWLK_SERVER = yes ]; then
 PACKAGE_TO_INSTALL=`echo $PACKAGE_TO_INSTALL | sed -e "s|spacewalk-client-release-el7||"`
fi
COMMAND="yum -y install "
for pkg in $PACKAGE_TO_INSTALL
do
  if rpm -qa | grep $pkg > /dev/null; then
     echo $pkg already installed
 else
    COMMAND="$COMMAND $pkg"
    RPM_INSTALL=yes
 fi
done

   if [ $RPM_INSTALL = yes ]; then
     if [ -f /var/run/yum.pid ]; then
       echo "Another yum command (PID:`cat /var/run/yum.pid`) holding a yum lock. Try running $0 later."
       exit
     fi
     if [ $OCI_ONLY = yes ]; then
        if  grep ol7_oci_included /etc/yum.repos.d/public-yum-ol7.repo  ; then
          yum-config-manager --enable ol7_oci_included
        fi
     fi
     echo $PACKAGE_TO_INSTALL
     $COMMAND
     if [ $? != 0 ]; then
       echo "Installation aborted. Exiting...."
       rm -f $RUN_FILE
       exit 
     fi
   fi
fi

yum-config-manager | grep ol7 | grep "^\[" | egrep -v -e "x86_64|aarch64" | sed -e "s|\[||" | sed -e "s|\]||" > $REPOLIST_FILE
mv /etc/yum.repos.d/public-yum-ol7.repo  /etc/yum.repos.d/public-yum-ol7.repo.sav
for file in `ls -1 /etc/yum.repos.d/*-ol7.repo.disabled`
do
  mv $file `echo $file | sed -e "s|.disabled$||"`
done

yum-config-manager | grep ol7 | grep "^\[" | egrep -v -e "x86_64|aarch64" | sed -e "s|\[||" | sed -e "s|\]||" > $REPOLIST_FILE_NEW

for repo in `cat $REPOLIST_FILE_NEW`
do
   if grep $repo $REPOLIST_FILE > /dev/null ; then
     echo  Repository $repo Fine
   else
     echo Disabling Repository $repo
     yum-config-manager --disable $repo > /dev/null
   fi
done

for file in `ls -1 /etc/yum.repos.d/*-ol7.repo.incomplete 2> /dev/null`
do
  if [ ! -f `echo $file | sed -e "s|.incomplete$||"` ]; then
    mv $file `echo $file | sed -e "s|.incomplete$||"`
  fi
done


rm -f $RUN_FILE
rm -f $REPOLIST_FILE $REPOLIST_FILE_NEW
